dj_oydiv.config package
=======================

Submodules
----------

dj_oydiv.config.default_settings module
---------------------------------------

.. automodule:: dj_oydiv.config.default_settings
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: dj_oydiv.config
    :members:
    :undoc-members:
    :show-inheritance:
